﻿///////////////////////////////////////////////////////////////////////////////
//
// (C) 2015 ICE TEA GROUP LLC - ALL RIGHTS RESERVED
//
// 
//
// ALL INFORMATION CONTAINED HEREIN IS, AND REMAINS
// THE PROPERTY OF ICE TEA GROUP LLC AND ITS SUPPLIERS, IF ANY.
// THE INTELLECTUAL PROPERTY AND TECHNICAL CONCEPTS CONTAINED
// HEREIN ARE PROPRIETARY TO ICE TEA GROUP LLC AND ITS SUPPLIERS
// AND MAY BE COVERED BY U.S. AND FOREIGN PATENTS, PATENT IN PROCESS, AND
// ARE PROTECTED BY TRADE SECRET OR COPYRIGHT LAW.
//
// DISSEMINATION OF THIS INFORMATION OR REPRODUCTION OF THIS MATERIAL
// IS STRICTLY FORBIDDEN UNLESS PRIOR WRITTEN PERMISSION IS OBTAINED
// FROM ICE TEA GROUP LLC.
//
///////////////////////////////////////////////////////////////////////////////

/**
 * wisej.ext.LocalStorage
 *
 * Provides methods and events to access the browser's local storage.
 */
qx.Class.define("wisej.ext.LocalStorage", {

	extend: qx.core.Object,

	// All Wisej components must include this mixin
	// to provide services to the Wisej core.
	include: [wisej.mixin.MWisejComponent],

	construct: function () {

		this.base(arguments);

		this.initSessionStorage();

	},

	properties: {

		/**
		 * Indicates whether to use session storage instead of local storage.
		 */
		sessionStorage: { init: false, check: "Boolean", apply: "_applySessionStorage" }
	},

	members: {

		/** The storage to use. */
		__storage: window.localStorage,

		/**
		 * Adds the specified key and value to the storage, or update that key's value if it already exists.
		 */
		setItem: function (key, value) {

			if (this.__storage)
				this.__storage.setItem(key, value);

		},

		/**
		 * Returns the value associated with the specified key.
		 */
		getItem: function (key, id)
		{
			if (this.__storage) {
				var data = {
					id: id,
					value: this.__storage.getItem(key)
				};

				this.fireDataEvent("callback", data);
			}
		},

		/**
		 * Removes the specified key from storage.
		 */
		removeItem: function (key) {

			if (this.__storage)
				this.__storage.removeItem(key);

		},

		/**
		 * Clears all stored keys.
		 */
		clear: function () {

			if (this.__storage)
				this.__storage.clear();

		},

		/**
		 * Applies the sessionStorage property.
		 */
		_applySessionStorage: function (value, old) {

			this.__storage = value ? window.sessionStorage : window.localStorage;

		}
	},

});
